@@ -8,10 +8,10 @@ import math
 import re
 import sys
 import time
-from typing import Iterable, Tuple, Union, Optional, Any, Type, List, Callable, Sequence, Dict, Set
+from typing import Tuple, Union, Optional, Any, Type, List, Callable, Sequence, Dict, Set, Collection
 
 from . import _msgs as msgs
-from ._helpers import null_terminate, SimpleError, Database, current_time
+from ._helpers import null_terminate, SimpleError, Database
 
 MAX_STRING_SIZE = 512 * 1024 * 1024
 SUPPORTED_COMMANDS: Dict[str, "Signature"] = dict()  # Dictionary of supported commands name => Signature
@@ -107,82 +107,6 @@ class CommandItem:
     __nonzero__ = __bool__  # For Python 2
 
 
-class Hash:  # type:ignore
-    DECODE_ERROR = msgs.INVALID_HASH_MSG
-    redis_type = b"hash"
-
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        super().__init__(*args, **kwargs)
-        self._expirations: Dict[bytes, int] = dict()
-        self._values: Dict[bytes, Any] = dict()
-
-    def _expire_keys(self):
-        removed = []
-        now = current_time()
-        for k in self._expirations:
-            if self._expirations[k] < now:
-                self._values.pop(k, None)
-                removed.append(k)
-        for k in removed:
-            self._expirations.pop(k, None)
-
-    def set_key_expireat(self, key: bytes, when_ms: int) -> int:
-        now = current_time()
-        if when_ms <= now:
-            self._values.pop(key, None)
-            self._expirations.pop(key, None)
-            return 2
-        self._expirations[key] = when_ms
-        return 1
-
-    def clear_key_expireat(self, key: bytes) -> bool:
-        return self._expirations.pop(key, None) is not None
-
-    def get_key_expireat(self, key: bytes) -> Optional[int]:
-        self._expire_keys()
-        return self._expirations.get(key, None)
-
-    def __getitem__(self, key: bytes) -> Any:
-        self._expire_keys()
-        return self._values.get(key)
-
-    def __contains__(self, key: bytes) -> bool:
-        self._expire_keys()
-        return self._values.__contains__(key)
-
-    def __setitem__(self, key: bytes, value: Any) -> None:
-        self._expirations.pop(key, None)
-        self._values[key] = value
-
-    def __delitem__(self, key):
-        self._values.pop(key, None)
-        self._expirations.pop(key, None)
-
-    def __len__(self):
-        return len(self._values)
-
-    def __iter__(self):
-        return iter(self._values)
-
-    def get(self, key: bytes, default: Any = None) -> Any:
-        return self._values.get(key, default)
-
-    def keys(self) -> Iterable[bytes]:
-        self._expire_keys()
-        return self._values.keys()
-
-    def values(self) -> Iterable[Any]:
-        return [v for k, v in self.items()]
-
-    def items(self) -> Iterable[Tuple[bytes, Any]]:
-        self._expire_keys()
-        return self._values.items()
-
-    def update(self, values: Dict[bytes, Any]) -> None:
-        self._expire_keys()
-        self._values.update(values)
-
-
 class RedisType:
     @classmethod
     def decode(cls, *args, **kwargs):  # type:ignore
@@ -425,6 +349,11 @@ class Signature:
         repeat: Tuple[Type[Union[RedisType, bytes]]] = (),  # type:ignore
         args: Tuple[str] = (),  # type:ignore
         flags: str = "",
+        server_types: Collection[str] = (
+            "redis",
+            "valkey",
+            "dragonfly",
+        ),  # supported server types: redis, dragonfly, valkey
     ):
         self.name = name
         self.func_name = func_name
@@ -432,6 +361,7 @@ class Signature:
         self.repeat = repeat
         self.flags = set(flags)
         self.command_args = args
+        self.server_types: Set[str] = set(server_types)
 
     def check_arity(self, args: Sequence[Any], version: Tuple[int]) -> None:
         if len(args) == len(self.fixed):
