@@ -28,7 +28,12 @@ class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
     def _connect(self) -> FakeSocket:
         if not self._server.connected:
             raise redis.ConnectionError(msgs.CONNECTION_ERROR_MSG)
-        return FakeSocket(self._server, db=self.db, lua_modules=self._lua_modules)
+        return FakeSocket(
+            self._server,
+            db=self.db,
+            lua_modules=self._lua_modules,
+            client_info=b"id=3 addr=127.0.0.1:57275 laddr=127.0.0.1:6379 fd=8 name= age=16 idle=0 flags=N db=0 sub=0 psub=0 ssub=0 multi=-1 qbuf=48 qbuf-free=16842 argv-mem=25 multi-mem=0 rbs=1024 rbp=0 obl=0 oll=0 omem=0 tot-mem=18737 events=r cmd=auth user=default redir=-1 resp=2",
+        )
 
     def can_read(self, timeout: Optional[float] = 0) -> bool:
         if not self._server.connected:
@@ -62,7 +67,7 @@ class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
                 raise redis.ConnectionError(msgs.CONNECTION_ERROR_MSG)
         else:
             response = self._sock.responses.get()
-        if isinstance(response, redis.ResponseError):
+        if isinstance(response, (redis.ResponseError, redis.AuthenticationError)):
             raise response
         if kwargs.get("disable_decoding", False):
             return response
@@ -100,6 +105,7 @@ class FakeRedisMixin:
             for ind, p in enumerate(parameters)
             if p.default != inspect.Parameter.empty
         }
+        kwds["server"] = server
         if not kwds.get("connection_pool", None):
             charset = kwds.get("charset", None)
             errors = kwds.get("errors", None)
@@ -114,9 +120,8 @@ class FakeRedisMixin:
                 "host",
                 "port",
                 "db",
-                # Ignoring because AUTH is not implemented
-                # 'username',
-                # 'password',
+                "username",
+                "password",
                 "socket_timeout",
                 "encoding",
                 "encoding_errors",
@@ -126,10 +131,10 @@ class FakeRedisMixin:
                 "health_check_interval",
                 "client_name",
                 "connected",
+                "server",
             }
             connection_kwargs = {
                 "connection_class": FakeConnection,
-                "server": server,
                 "version": version,
                 "server_type": server_type,
                 "lua_modules": lua_modules,
@@ -150,11 +155,7 @@ class FakeRedisMixin:
         pool = redis.ConnectionPool.from_url(*args, **kwargs)
         # Now override how it creates connections
         pool.connection_class = FakeConnection
-        # Using username and password fails since AUTH is not implemented.
-        # https://github.com/cunla/fakeredis-py/issues/9
-        pool.connection_kwargs.pop("username", None)
-        pool.connection_kwargs.pop("password", None)
-        return cls(connection_pool=pool)
+        return cls(connection_pool=pool, *args, **kwargs)
 
 
 class FakeStrictRedis(FakeRedisMixin, redis.StrictRedis):  # type: ignore
