@@ -173,6 +173,8 @@ class FakeConnection(FakeBaseConnectionMixin, redis_async.Connection):
             response = await self._reader.read(0) if can_read and self._reader else None
         if isinstance(response, redis_async.ResponseError):
             raise response
+        if kwargs.get("disable_decoding", False):
+            return response
         return self._decode(response)
 
     def repr_pieces(self) -> List[Tuple[str, Any]]:
@@ -206,6 +208,7 @@ class FakeRedis(redis_async.Redis):
         server: Optional[_server.FakeServer] = None,
         connected: bool = True,
         version: VersionType = (7,),
+        server_type: str = "redis",
         lua_modules: Optional[Set[str]] = None,
         **kwargs: Any,
     ) -> None:
@@ -230,6 +233,7 @@ class FakeRedis(redis_async.Redis):
                 connection_class=FakeConnection,
                 max_connections=max_connections,
                 version=version,
+                server_type=server_type,
                 lua_modules=lua_modules,
             )
             connection_pool = redis_async.ConnectionPool(**connection_kwargs)  # type:ignore
@@ -256,6 +260,8 @@ class FakeRedis(redis_async.Redis):
         self = super().from_url(url, **kwargs)
         pool = self.connection_pool  # Now override how it creates connections
         pool.connection_class = FakeConnection
+        pool.connection_kwargs.setdefault("version", "7.4")
+        pool.connection_kwargs.setdefault("server_type", "redis")
         pool.connection_kwargs.pop("username", None)
         pool.connection_kwargs.pop("password", None)
         return self
