@@ -14,10 +14,9 @@ from fakeredis._commands import (
     CommandItem,
     SortFloat,
     delete_keys,
-    Hash,
 )
 from fakeredis._helpers import compile_pattern, SimpleError, OK, casematch, Database, SimpleString
-from fakeredis._zset import ZSet
+from fakeredis.model import ZSet, Hash, ExpiringMembersSet
 
 
 class GenericCommandsMixin:
@@ -110,11 +109,7 @@ class GenericCommandsMixin:
                 ret += 1
         return ret
 
-    @command(
-        name="expire",
-        fixed=(Key(), Int),
-        repeat=(bytes,),
-    )
+    @command(name="EXPIRE", fixed=(Key(), Int), repeat=(bytes,))
     def expire(self, key: CommandItem, seconds: int, *args: bytes) -> int:
         res = self._expireat(key, self._db.time + seconds, *args)
         return res
@@ -228,7 +223,7 @@ class GenericCommandsMixin:
 
     @command(name="SORT", fixed=(Key(),), repeat=(bytes,))
     def sort(self, key, *args):
-        if key.value is not None and not isinstance(key.value, (set, list, ZSet)):
+        if key.value is not None and not isinstance(key.value, (ExpiringMembersSet, list, ZSet)):
             raise SimpleError(msgs.WRONGTYPE_MSG)
         (
             asc,
